@@ -30,6 +30,20 @@ import datetime
 from .. import hypixel, utils
 
 
+class APIKey:
+    def __init__(self, data):
+        self.key = data.get("record", {}).get("key")
+        self.owner = data.get("record", {}).get("owner")
+        self.limit = data.get("record", {}).get("limit")
+        self.queries = APIKeyQueries(data)
+
+
+class APIKeyQueries:
+    def __init__(self, data):
+        self.minute = data.get("record", {}).get("queriesInPastMin")
+        self.all = data.get("record", {}).get("queries")
+
+
 class MojangPlayer:
     """
     The response from a call to the Mojang API
